"""Shared environment variable names used for container setup."""

AICAGE_UID = "AICAGE_UID"
AICAGE_GID = "AICAGE_GID"
AICAGE_HOST_USER = "AICAGE_HOST_USER"
AICAGE_HOME = "AICAGE_HOME"
AICAGE_HOST_IS_LINUX = "AICAGE_HOST_IS_LINUX"
AICAGE_WORKSPACE = "AICAGE_WORKSPACE"

DOCKER_HOST = "DOCKER_HOST"
WINDOWS_DOCKER_HOST = "tcp://host.docker.internal:2375"
